@@ -39,7 +39,6 @@
 #endif
 
 #ifdef IPFILTER
-# include <fcntl.h>
 # include <sys/ioctl.h>
 # include <netinet/in_systm.h>
 # include <netinet/ip.h>
@@ -54,8 +53,14 @@
 # include <tcpd.h>
 #endif
 
+/* For Solaris */
+#ifndef INADDR_NONE
+# define INADDR_NONE		(in_addr_t)-1
+#endif
+
+/* For Linux */
 #if defined(SIGCLD) && !defined(SIGCHLD)
-# define SIGCHLD SIGCLD
+# define SIGCHLD			SIGCLD
 #endif
 
 #ifndef _PATH_DEVNULL
@@ -93,7 +98,7 @@
 /*
  * Typedefs.
  */
-typedef unsigned long	ipaddr_t;
+typedef unsigned long	ip_address_t;
 typedef unsigned char	byte_t;
 
 typedef struct buffer_
@@ -133,11 +138,11 @@ typedef struct connection_
  */
 static void usage(char *prog, char *opt);
 static short getportnum(char *portnum);
-static ipaddr_t getipaddress(char *ipaddr);
+static ip_address_t getipaddress(char *ipaddr);
 static uid_t getuserid(char *user);
 static uid_t getgroupid(uid_t uid);
-static int bind_to_port(ipaddr_t bind_ip, short bind_port);
-static int connect_to_proxy(ipaddr_t ip, short port);
+static int bind_to_port(ip_address_t bind_ip, short bind_port);
+static int connect_to_proxy(ip_address_t ip, short port);
 static void lookup_hostname(struct sockaddr_in *addr, char *hostname, int hostlen, int needed);
 static void server_main_loop(int sock, char *server_hostname, short server_port);
 static void trans_proxy(int sock, struct sockaddr_in *addr,
@@ -181,6 +186,7 @@ static int				natdev = -1;
  * The syslog levels for tcp_wrapper checking.
  */
 int						deny_severity;
+int						allow_severity;
 #endif
 
 /*
@@ -190,7 +196,7 @@ int main(int argc, char **argv)
 {
 	int					arg;
 	int					run_as_server = 0;
-	ipaddr_t			bind_ip = INADDR_ANY;
+	ip_address_t		bind_ip = INADDR_ANY;
 	short				bind_port = -1;
 	char 				*server_hostname = NULL;
 	short				server_port = -1;
@@ -546,7 +552,7 @@ static short getportnum(char *portnum)
 	struct servent	*serv;
 	short			port;
 
-	for (port = 0; isdigit(*digits); ++digits)
+	for (port = 0; isdigit((int)*digits); ++digits)
 	{
 		port = (port * 10) + (*digits - '0');
 	}
@@ -576,10 +582,10 @@ static short getportnum(char *portnum)
 /*
  * Return the IP address of the specified host.
  */
-static ipaddr_t getipaddress(char *ipaddr)
+static ip_address_t getipaddress(char *ipaddr)
 {
 	struct hostent	*host;
-	ipaddr_t		ip;
+	ip_address_t	ip;
 
 	if (((ip = inet_addr(ipaddr)) == INADDR_NONE)
 	    &&
@@ -658,7 +664,7 @@ static uid_t getgroupid(uid_t uid)
 /*
  * Bind to the specified ip and port.
  */
-static int bind_to_port(ipaddr_t bind_ip, short bind_port)
+static int bind_to_port(ip_address_t bind_ip, short bind_port)
 {
 	struct sockaddr_in	addr;
 	int					sock;
@@ -713,7 +719,7 @@ static int bind_to_port(ipaddr_t bind_ip, short bind_port)
 /*
  * Connect to the proxy server.
  */
-static int connect_to_proxy(ipaddr_t ip, short port)
+static int connect_to_proxy(ip_address_t ip, short port)
 {
 	struct sockaddr_in	addr;
 	int					sock;
@@ -763,9 +769,9 @@ static int connect_to_proxy(ipaddr_t ip, short port)
  */
 static void lookup_hostname(struct sockaddr_in *addr, char *hostname, int hostlen, int needed)
 {
+#ifdef DNS_LOOKUPS
 	struct hostent	*host;
 
-#ifdef DNS_LOOKUPS
 	if (needed)
 	{
 		if ((host = gethostbyaddr((char *)&addr->sin_addr,
@@ -970,7 +976,7 @@ static void server_main_loop(int sock, char *server_hostname, short server_port)
 static void trans_proxy(int sock, struct sockaddr_in *from_addr,
 						char *server_hostname, short server_port)
 {
-	ipaddr_t			server_ip;
+	ip_address_t		server_ip;
 	connection_t		conn;
 	int					length;
 	int					max_fd;
@@ -1239,7 +1245,9 @@ static int process_client_request(connection_t *conn, size_t last_read)
 	size_t	send_size;
 	int		c;
 	int		request_change;
+#if defined(LOG_TO_SYSLOG) || defined(LOG_TO_FILE)
 	char	client_host[HOSTNAME_SIZE];
+#endif
 	char	request_buffer[BUFFER_SIZE];
 	char	request_port[16];
 #if defined(LOG_TO_SYSLOG) || defined(LOG_TO_FILE)
@@ -1712,8 +1720,12 @@ static int process_client_request(connection_t *conn, size_t last_read)
 				memcpy(&request_buffer[send_size], conn->host_header, conn->host_header_length);
 				send_size += conn->host_header_length;
 				conn->url_end_offset += conn->host_header_length;
-				if (ntohs(conn->dest_addr.sin_port) != 80 &&
-				    strchr(conn->host_header, ':') == NULL)
+				if ((ntohs(conn->dest_addr.sin_port) != 80) &&
+#ifdef USE_STRSTR_BUG
+				    (strstr(conn->host_header, ":") == NULL))
+#else
+				    (strchr(conn->host_header, ':') == NULL))
+#endif
 				{
 					sprintf(request_port, ":%u", ntohs(conn->dest_addr.sin_port));
 					memcpy(&request_buffer[send_size], request_port, strlen(request_port));
